@@ -8,6 +8,7 @@ from __future__ import annotations
 import os.path
 import re
 import sys
+import warnings
 
 from flaky import flaky
 import pytest
@@ -44,7 +45,8 @@ class ThreadingTest(CoverageTest):
             fromMainThread()
             other.join()
             """,
-            [1, 3, 4, 6, 7, 9, 10, 12, 13, 14, 15], "10",
+            lines=[1, 3, 4, 6, 7, 9, 10, 12, 13, 14, 15],
+            missing="10",
         )
 
     def test_thread_run(self) -> None:
@@ -64,7 +66,8 @@ class ThreadingTest(CoverageTest):
             thd.start()
             thd.join()
             """,
-            [1, 3, 4, 5, 6, 7, 9, 10, 12, 13, 14], "",
+            lines=[1, 3, 4, 5, 6, 7, 9, 10, 12, 13, 14],
+            missing="",
         )
 
 
@@ -83,7 +86,8 @@ class RecursionTest(CoverageTest):
             recur(495)  # We can get at least this many stack frames.
             i = 8       # and this line will be traced
             """,
-            [1, 2, 3, 5, 7, 8], "",
+            lines=[1, 2, 3, 5, 7, 8],
+            missing="",
         )
 
     def test_long_recursion(self) -> None:
@@ -99,7 +103,8 @@ class RecursionTest(CoverageTest):
 
                     recur(100000)  # This is definitely too many frames.
                     """,
-                    [1, 2, 3, 5, 7], "",
+                    lines=[1, 2, 3, 5, 7],
+                    missing="",
                 )
 
     def test_long_recursion_recovery(self) -> None:
@@ -193,9 +198,9 @@ class MemoryLeakTest(CoverageTest):
         fails = 0
         for _ in range(10):
             ram_0 = osinfo.process_ram()
-            self.check_coverage(code.replace("ITERS", "10"), lines, "")
+            self.check_coverage(code.replace("ITERS", "10"), lines=lines, missing="")
             ram_10 = osinfo.process_ram()
-            self.check_coverage(code.replace("ITERS", "10000"), lines, "")
+            self.check_coverage(code.replace("ITERS", "10000"), lines=lines, missing="")
             ram_10k = osinfo.process_ram()
             # Running the code 10k times shouldn't grow the ram much more than
             # running it 10 times.
@@ -206,9 +211,16 @@ class MemoryLeakTest(CoverageTest):
         if fails > 8:
             pytest.fail("RAM grew by %d" % (ram_growth))      # pragma: only failure
 
-    @pytest.mark.skipif(not testenv.C_TRACER, reason="Only the C tracer has refcounting issues")
-    # In fact, sysmon explicitly holds onto all code objects,
-    # so this will definitely fail with sysmon.
+    @pytest.mark.skipif(
+        not testenv.C_TRACER,
+        reason="Only the C tracer has refcounting issues",
+        # In fact, sysmon explicitly holds onto all code objects,
+        # so this will definitely fail with sysmon.
+    )
+    @pytest.mark.skipif(
+        env.PYVERSION[:2] == (3, 13) and not env.GIL,
+        reason = "3.13t never frees code objects: https://github.com/python/cpython/pull/131989",
+    )
     @pytest.mark.parametrize("branch", [False, True])
     def test_eval_codeobject_leak(self, branch: bool) -> None:
         # https://github.com/nedbat/coveragepy/issues/1924
@@ -221,8 +233,8 @@ class MemoryLeakTest(CoverageTest):
         # one of our loops only increased the footprint by a small amount.
         base = osinfo.process_ram()
         deltas = []
-        for _ in range(10):
-            self.check_coverage(code, [1, 2, 3], "", branch=branch)
+        for _ in range(30):
+            self.check_coverage(code, lines=[1, 2, 3], missing="", branch=branch)
             now = osinfo.process_ram()
             deltas.append(now - base)
             print(f"Mem delta: {(now - base)//1024}")
@@ -454,7 +466,11 @@ class DoctestTest(CoverageTest):
             doctest.testmod(sys.modules[__name__])  # we're not __main__ :(
             ''')
         cov = coverage.Coverage()
-        self.start_import_stop(cov, "the_doctest")
+        with warnings.catch_warnings():
+            # Doctest calls pdb which opens ~/.pdbrc without an encoding argument,
+            # but we don't care. PYVERSIONS: this was needed for 3.10 only.
+            warnings.filterwarnings("ignore", r".*'encoding' argument not specified.*")
+            self.start_import_stop(cov, "the_doctest")
         data = cov.get_data()
         assert len(data.measured_files()) == 1
         lines = sorted_lines(data, data.measured_files().pop())
@@ -498,7 +514,7 @@ class GettraceTest(CoverageTest):
 
     def test_setting_new_trace_function(self) -> None:
         # https://github.com/nedbat/coveragepy/issues/436
-        if testenv.SETTRACE_CORE:
+        if testenv.SETTRACE_CORE or not env.PYBEHAVIOR.branch_right_left:
             missing = "5-7, 13-14"
         else:
             missing = "5-7"
@@ -588,7 +604,7 @@ class ExecTest(CoverageTest):
             """)
         self.make_file("main.py", """\
             namespace = {'var': 17}
-            with open("to_exec.py") as to_exec_py:
+            with open("to_exec.py", encoding="utf-8") as to_exec_py:
                 code = compile(to_exec_py.read(), 'to_exec.py', 'exec')
                 exec(code, globals(), namespace)
             \n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n
